@@ -7,7 +7,7 @@
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
- * as published by the Free Software Foundation; either version 2    
+ * as published by the Free Software Foundation; either version 3    
  * of the License, or any later version.                             
  *                                                                   
  *                                                                   
@@ -18,21 +18,19 @@
  *                                                                   
  * You should have received a copy of the GNU General Public License 
  * along with this program; if not, write to the Free Software       
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,            
- * MA  02111-1307, USA.                                              
+ * Foundation, Inc., 51 Franklin Street, Boston,            
+ * MA  02110-1301, USA.                                              
  ****/
 
 
 
 #include <stdio.h>
 
-#include <X11/X.h>
-#include <X11/Xproto.h>
-
-
+#ifndef XNEE_DATASTRINGS_H 
+#define XNEE_DATASTRINGS_H 
 
 void 
-xnee_init_names();
+xnee_init_names(void);
 
 
 /**
@@ -44,6 +42,18 @@ xnee_init_names();
 int
 xnee_data2int(int type, char *dat);
 
+
+/**
+ * Get the integer value from X11 data dat
+ * @param dat
+ * @param type type is saved here
+ * @return int
+ */
+int
+xnee_data2int_special(int *type, char *dat);
+
+
+
 /**
  * Get the integer value from event ev
  * @param ev
@@ -102,12 +112,24 @@ xnee_int2event(int ev);
 char *
 xnee_int2request(int req);
 
+char *
+xnee_int2error(int err);
 
-char ** 
-xnee_get_event_names();
 
-char ** 
-xnee_get_error_names();
+struct data_description*
+xnee_get_event_names(void);
 
-char ** 
-xnee_get_request_names();
+struct data_description*
+xnee_get_error_names(void);
+
+struct data_description*
+xnee_get_request_names(void);
+
+struct data_description*
+xnee_get_reply_names(void);
+
+char*
+xnee_int2data(int type, int dat);
+
+
+#endif /*  XNEE_DATASTRINGS_H  */
