@@ -5,7 +5,7 @@
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
  *                      2004, 2005, 2006, 2007, 2008
- *                      2009, 2010, 2011  Henrik Sandklef                    
+ *                      2009, 2010, 2011, 2013  Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -884,4 +884,11 @@ xnee_unset_forced_core_device_events(xnee_data *xd);
 int
 xnee_is_forced_core_device_events(xnee_data *xd);
 
+int 
+xnee_get_max_nr_of_moves(xnee_data *xd);
+
+int 
+xnee_set_max_nr_of_moves(xnee_data *xd, int moves);
+
+
 #endif /* XNEE_SETGET_H */ 
